@@ -59,7 +59,8 @@ mpfr.default <- function(x, precBits, base = 10, rnd.mode = c('N','D','U','Z','A
     if(missing(precBits)) {
 	precBits <- getPrec(x, base = base, doNumeric = FALSE)
     }
-    stopifnot(precBits >= 2, ## libmpfr exits (after good error message) for precBits == 1
+    stopifnot(2 <= precBits, ## libmpfr exits (after good error message) for precBits == 1
+                   precBits <= .Machine$integer.max,
               is.character(rnd.mode <- toupper(rnd.mode)))
     rnd.mode <- match.arg(rnd.mode)
 
@@ -95,8 +96,10 @@ setAs("logical", "mpfr", function(from) .mpfr(from,   2L))
 ## TODO?  base=16 for "0x" or "0X" prefix -- but base must have length 1 ..
 setAs("character", "mpfr", function(from) mpfr(from))
 
-setAs("mpfr", "numeric", function(from) .Call(mpfr2d, from, rnd.mode="N"))
-setAs("mpfr", "integer", function(from) .Call(mpfr2i, from, rnd.mode="N"))
+.mpfr2d <- function(from) .Call(mpfr2d, from, rnd.mode="N")
+.mpfr2i <- function(from) .Call(mpfr2i, from, rnd.mode="N")
+setAs("mpfr", "numeric", .mpfr2d)
+setAs("mpfr", "integer", .mpfr2i)
 setMethod("as.numeric", "mpfr", function(x, rnd.mode="N") .Call(mpfr2d, x, rnd.mode))
 ## "Z": round towards [Z]ero -- crucial for as.integer() :
 setMethod("as.integer", "mpfr", function(x, rnd.mode="Z") .Call(mpfr2i, x, rnd.mode))
@@ -190,7 +193,8 @@ frexpMpfr <- function(x, rnd.mode = c('N','D','U','Z','A')) {
 
 
 formatMpfr <-
-    function(x, digits = NULL, trim = FALSE, scientific = NA,
+    function(x, digits = NULL, # digits = NULL : use as many digits "as needed"
+             trim = FALSE, scientific = NA,
 	     maybe.full = (!is.null(digits) && is.na(scientific)) || isFALSE(scientific),
              base = 10, showNeg0 = TRUE, max.digits = Inf,
 	     big.mark = "", big.interval = 3L,
@@ -200,7 +204,7 @@ formatMpfr <-
              exponent.plus = TRUE,
 	     zero.print = NULL, drop0trailing = FALSE, ...)
 {
-    ## digits = NULL : use as many digits "as needed"
+    if(!length(x)) return(character())
     ff <- .mpfr2str(x, digits, maybe.full=maybe.full, base=base) # (checks its args!)
     ## FIXME/TODO: If have very large numbers, but not high precision, should detect it
     ## ==========  and use  maybe.full = FALSE also for the default scientific = NA
